==> fd-help-801.2020.08.26-noarch-1.txz: usr/share/doc/fd-help/defaults.md <==
%%textdomain fatdoghelp
![ ](fatdog64.png)
# How to change default programs (default browser, default editor, etc)?

### Question

I have installed another web browser.

How do I change it so that it is the one used by default?

### Answer

Edit /etc/defaultprograms with your favorite text editor and change the entries there. 

To change the default browser from "seamonkey-spot" to firefox (without spot), for example, change the DEF_BROWSER entry in that file and replace the text within quotes.

You can do the same for the rest of the applications listed there: draw, html editor, paint, media player, etc.

Since Fatdog64-710b you can also use the "Fatdog64 Edit Default Programs" GUI available in Control Panel on the "Desktop" tab.
This method changes the default applications on a per-user basis (*~/.fatdog/defaultprograms*).

**Note:** Doing this will only change the defaults for programs that honour a Puppy-like model of default programs.

Unfortunately there is no single unified way to change the "default" programs unless you run a comprehensive desktop environment like KDE or Gnome.

Every program has its own way of keeping track of what it thinks of as the *default*.

XDG-compliant programs, for example SpaceFM, make use of /usr/share/applications/mimeapps.list and /usr/share/applications/defaults.list (see [here (freedesktop.org)](http://standards.freedesktop.org/mime-apps-spec/mime-apps-spec-1.0.html) for details).

Other file managers like XFE or ROX-Filer have their own ways of keeping default programs.

You will have to consult the documentation of each individual program if the method described above doesn't seem to work.

==> fd-help-899.0-noarch-1.txz: usr/share/doc/fd-help/defaults.md <==
%%textdomain fatdoghelp
![ ](fatdog64.png)
# How to change default programs (default browser, default editor, etc)?

### Question

I have installed another web browser.

How do I change it so that it is the one used by default?

### Answer

Edit /etc/defaultprograms with your favorite text editor and change the entries there. 

To change the default browser from "seamonkey-spot" to firefox (without spot), for example, change the DEF_BROWSER entry in that file and replace the text within quotes.

You can do the same for the rest of the applications listed there: draw, html editor, paint, media player, etc.

Since Fatdog64-710b you can also use the "Fatdog64 Edit Default Programs" GUI available in Control Panel on the "System" tab.
This method changes the default applications on a per-user basis (*~/.fatdog/defaultprograms*).

**Note:** Doing this will only change the defaults for programs that honour a Puppy-like model of default programs.

Unfortunately there is no single unified way to change the "default" programs unless you run a comprehensive desktop environment like KDE or Gnome.

Every program has its own way of keeping track of what it thinks of as the *default*.

XDG-compliant programs, for example SpaceFM, make use of /usr/share/applications/mimeapps.list and /usr/share/applications/defaults.list (see [here (freedesktop.org)](http://standards.freedesktop.org/mime-apps-spec/mime-apps-spec-1.0.html) for details).

Other file managers like XFE or ROX-Filer have their own ways of keeping default programs.

You will have to consult the documentation of each individual program if the method described above doesn't seem to work.
